<?php

/*-----------------------------------------------------------------------------------
- Default
----------------------------------------------------------------------------------- */

add_action( 'after_setup_theme', 'wellcenter_theme_setup' );

function wellcenter_theme_setup() {
	global $content_width;

	/* Set the $content_width for things such as video embeds. */
	if ( !isset( $content_width ) )
		$content_width = 750;

	/* Add theme support for automatic feed links. */
	add_theme_support( 'post-formats', array( 'video','audio', 'gallery','quote', 'link', 'aside' ) );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	
	/* Add theme support for post thumbnails (featured images). */	
	add_theme_support('post-thumbnails');
	add_image_size('wellcenter_slider', 1920, 850, true ); 		//(cropped)
	add_image_size('wellcenter_single', 864, 440, true ); 		//(cropped)
	add_image_size('wellcenter_blog', 390, 440, true ); 			//(cropped)
	add_image_size('wellcenter_mag', 540, 400, true ); 			//(cropped)
	add_image_size('wellcenter_grid', 540, 640, true ); 			//(cropped)
	add_image_size('wellcenter_related', 236, 236, true ); 		//(cropped)
	add_image_size('wellcenter_tabs', 90, 90, true ); 			//(cropped)

	/* Add custom menus */
	register_nav_menus(array(
		'main-menu' => esc_html__( 'Main Menu','wellcenter' ),
		'add-menu' => esc_html__( 'Additional Menu','wellcenter' ),
		'bottom-menu' => esc_html__( 'Footer Menu','wellcenter' ),
	));

	/* Add your sidebars function to the 'widgets_init' action hook. */
	add_action( 'widgets_init', 'wellcenter_register_sidebars' );
	
	/* Make theme available for translation */
	load_theme_textdomain('wellcenter', get_template_directory() . '/lang' );

}

function wellcenter_register_sidebars() {
	
	register_sidebar(
		array(
			'name' => esc_html__( 'Sidebar','wellcenter' ),
			'id' => 'tmnf-sidebar',
			'description' => esc_html__( 'Sidebar widget section','wellcenter' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget tmnf_border"><span>',
			'after_title' => '</span></h4>'
		));

	//footer widgets
	register_sidebar(array('name' => esc_html__( 'Footer 1','wellcenter' ),'id' => 'tmnf-footer-1','description' => esc_html__( 'Widget section in footer - left','wellcenter' ),'before_widget' => '','after_widget' => '','before_title' => '<h4 class="widget tmnf_border small_title">','after_title' => '</h4>'));
	register_sidebar(array('name' => esc_html__( 'Footer 2','wellcenter' ),'id' => 'tmnf-footer-2','description' => esc_html__( 'Widget section in footer - center/left','wellcenter' ),'before_widget' => '','after_widget' => '','before_title' => '<h4 class="widget tmnf_border small_title">','after_title' => '</h4>'));
	register_sidebar(array('name' => esc_html__( 'Footer 3','wellcenter' ),'id' => 'tmnf-footer-3','description' => esc_html__( 'Widget section in footer - center/right','wellcenter' ),'before_widget' => '','after_widget' => '','before_title' => '<h4 class="widget tmnf_border small_title">','after_title' => '</h4>'));
	register_sidebar(array('name' => esc_html__( 'Footer 4','wellcenter' ),'id' => 'tmnf-footer-4','description' => esc_html__( 'Widget section in footer - right','wellcenter' ),'before_widget' => '','after_widget' => '','before_title' => '<h4 class="widget tmnf_border small_title">','after_title' => '</h4>'));

	
	
	
	//woo widgets
	if ( class_exists( 'WooCommerce' ) ) {
		register_sidebar(
			array(
				'name' => esc_html__( 'Shop Sidebar','wellcenter' ),
				'id' => 'tmnf-shop-sidebar',
				'description' => esc_html__( 'Sidebar widget section (displayed on shop pages)','wellcenter' ),
				'before_widget' => '<div class="sidebar_item">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="widget tmnf_border"><span>',
				'after_title' => '</span></h5>'
			)
		);
	}
	
}

	
/*-----------------------------------------------------------------------------------
- Framework - Please refrain from editing this section 
----------------------------------------------------------------------------------- */


// Set path to Framework and theme specific functions
$functions_path = get_template_directory() . '/functions/';

// Theme specific functionality
require_once ($functions_path . 'admin-functions.php');					// Custom functions and plugins

// Add Redux options panel
if ( !isset( $themnific_redux ) && file_exists( get_template_directory()  . '/redux-framework/redux-themnific.php' ) ) {
    require_once( get_template_directory()  . '/redux-framework/redux-themnific.php' );
}

	
/*-----------------------------------------------------------------------------------
- Enqueues scripts and styles for front end
----------------------------------------------------------------------------------- */ 

function wellcenter_enqueue_style() {
	
	// main stylesheet
	wp_enqueue_style('wellcenter-style', get_stylesheet_uri());
	
	// wellcenter addons
	wp_enqueue_style('wellpress-addons', get_template_directory_uri() .	'/styles/wellpress-addons.css');
	
	// Font Awesome css	
	wp_enqueue_style('fontawesome', get_template_directory_uri() .	'/styles/fontawesome.css');
	
}
add_action( 'wp_enqueue_scripts', 'wellcenter_enqueue_style' );

// themnific custom css + chnage the order of how the sytlesheets are loaded, and overrides WooCommerce styles.
function wellcenter_custom_order() {
	
	// place wooCommerce styles before our main stlesheet
	if ( class_exists( 'WooCommerce' ) ) {
		wp_dequeue_style( 'woocommerce_frontend_styles' );
		wp_enqueue_style('woocommerce-frontend-styles', plugins_url() .'/woocommerce/assets/css/woocommerce.css');
	
		wp_enqueue_style('wellcenter-woo-custom', get_template_directory_uri().	'/styles/woo-custom.css');
		wp_enqueue_style('wellcenter-mobile', get_template_directory_uri().'/style-mobile.css');
	} else {
		wp_enqueue_style('wellcenter-mobile', get_template_directory_uri().'/style-mobile.css');
	}
}
add_action('wp_enqueue_scripts', 'wellcenter_custom_order');



function wellcenter_enqueue_script() {	

		// Load Common scripts	
		wp_enqueue_script('wellcenter-ownscript', get_template_directory_uri() .'/js/ownScript.js',array( 'jquery' ),'', true);		
		
		// Singular comment script		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );

}
	
add_action('wp_enqueue_scripts', 'wellcenter_enqueue_script');


/*-----------------------------------------------------------------------------------
- Include accessible
----------------------------------------------------------------------------------- */

include_once (get_template_directory() . '/functions/aria-walker-nav-menu.php');



/*-----------------------------------------------------------------------------------
- TGM_Plugin_Activation class.
----------------------------------------------------------------------------------- */
require_once get_template_directory()  . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'wellcenter_register_required_plugins' );
function wellcenter_register_required_plugins() {

    $plugins = array(
	

        // redux-framework
        array(
            'name'				=> esc_html__( 'Redux Framework','wellcenter' ),
            'slug'      		=> 'redux-framework',
            'required'  		=> true,
        ),
        // elementor
        array(
            'name'				=> esc_html__( 'Elementor','wellcenter' ),
            'slug'      		=> 'elementor',
            'required'  		=> true,
        ),            
		// wellcenter-addons
        array(
            'name'				=> esc_html__( 'WellPress Addons','wellcenter' ),
            'slug'      		=> 'wellpress-addons',
			'source'            => get_template_directory() . '/plugin/wellpress-addons.zip', // The plugin source.
            'required'  		=> true,
        ),
        // give
        array(
            'name'				=> esc_html__( 'GiveWP','wellcenter' ),
            'slug'      		=> 'give',
            'required'  		=> false,
        ),
        // one-click-demo-import
        array(
            'name'				=> esc_html__( 'One Click Demo Import','wellcenter' ),
            'slug'      		=> 'one-click-demo-import',
            'required'  		=> false,
        ),

    );
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins','wellcenter' ),
            'menu_title'                      => esc_html__( 'Install Plugins','wellcenter' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s','wellcenter' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.','wellcenter' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.','This theme requires the following plugins: %1$s.','wellcenter' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.','This theme recommends the following plugins: %1$s.','wellcenter' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','wellcenter' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','wellcenter' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','wellcenter' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','wellcenter' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','wellcenter' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','wellcenter' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','wellcenter' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','wellcenter' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer','wellcenter' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.','wellcenter' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s','wellcenter' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}

	
/*-----------------------------------------------------------------------------------
- Other theme functions
----------------------------------------------------------------------------------- */

// icons - font awesome
if ( ! function_exists ( 'wellcenter_icon' ) ) {
	function wellcenter_icon() {
		if(has_post_format('audio')) {return '<i title="'. esc_attr__('Audio','wellcenter').'" class="tmnf_icon fas fa-volume-up"></i>';
		}elseif(has_post_format('gallery')) {return '<i title="'. esc_attr__('Gallery','wellcenter').'" class="tmnf_icon fas fa-camera"></i>';
		}elseif(has_post_format('image')) {return '<i title="'. esc_attr__('Image','wellcenter').'" class="tmnf_icon fas fa-camera"></i>';	
		}elseif(has_post_format('link')) {return '<i title="'. esc_attr__('Link','wellcenter').'" class="tmnf_icon fas fa-link"></i>';			
		}elseif(has_post_format('quote')) {return '<i title="'. esc_attr__('Quote','wellcenter').'" class="tmnf_icon fas fa-quote-right"></i>';		
		}elseif(has_post_format('video')) {return '<i title="'. esc_attr__('Video','wellcenter').'" class="tmnf_icon fas fa-play-circle"></i>';
		} 	
	}
}


// new excerpt function
// Old Shorten Excerpt text for use in theme
function wellcenter_excerpt($text, $chars = 1620) {
	$text = $text." ";
	$text = substr($text,0,$chars);
	$text = substr($text,0,strrpos($text,' '));
	$text = $text."";
	return $text;
}

function wellcenter_trim_excerpt($text) {
     $text = str_replace('[', '', $text);
     $text = str_replace(']', '', $text);
     return $text;
    }
add_filter('get_the_excerpt', 'wellcenter_trim_excerpt');

// excerpt class
function wellcenter_class_to_excerpt( $excerpt ){
    return '<div class="tmnf_excerpt">'.$excerpt.'</div>';
}
add_action('the_excerpt','wellcenter_class_to_excerpt');


// meta sections
if ( ! function_exists ( 'wellcenter_meta_cat' ) ) {
	function wellcenter_meta_cat() { ?>   
		<p class="tmnf_meta tmnf_meta_categs <?php foreach((get_the_category()) as $category) {echo esc_attr($category->slug) . '_category_color ';  } ?> <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
        <span class="categs"><?php the_category(' • ') ?></span>
		</p>
	<?php }
}
if ( ! function_exists ( 'wellcenter_meta_date' ) ) {
	function wellcenter_meta_date() { ?>   
		<p class="tmnf_meta <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?></span>
		</p>
	<?php }
}

if ( ! function_exists ( 'wellcenter_meta_front' ) ) {
	function wellcenter_meta_front() { ?>    
		<p class="tmnf_meta meta_front <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?><span class="meta_divider">&bull;</span></span>
            <?php 
				echo '<span class="author">';
				echo '<span class="author_by">' ;
				esc_html_e('by','wellcenter') ;
				echo '</span>'; 
				the_author_posts_link();
				echo '</span>';	?>
		</p>
	<?php
	}
}

if ( ! function_exists ( 'wellcenter_meta_full' ) ) {
	function wellcenter_meta_full() { ?>    
		<p class="tmnf_meta tmnf_meta_full <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?><span class="meta_divider">&bull;</span></span>
			<span class="categs"><?php the_category(', ') ?><span class="meta_divider">&bull;</span></span>
			<?php echo '<span class="author">'; the_author_posts_link();echo '</span>';	?>
		</p>
	<?php
	}
}

if ( ! function_exists ( 'wellcenter_meta_more' ) ) {
	function wellcenter_meta_more() { ?>   
        <p class="tmnf_meta tmnf_meta_more tranz">
            <a class="ribbon" href="<?php the_permalink() ?>"><?php esc_html_e('Read More','wellcenter');?> &rarr;</a>
        </p>
	<?php }
}



// menu description
function wellcenter_nav_description( $item_output, $item, $depth, $args ) {
    if ( !empty( $item->description ) ) {
        $item_output = str_replace( $args->link_after . '</a>', '<span class="menu-item-description tranz">' . $item->description . '</span>' . $args->link_after . '</a>', $item_output );
    }
 
    return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'wellcenter_nav_description', 10, 4 );

//author box - additional links
if ( ! function_exists ( 'wellcenter_new_contactmethods' ) ) {
	function wellcenter_new_contactmethods( $contactmethods ) {
		$contactmethods['twitter'] = 'Twitter';
		$contactmethods['facebook'] = 'Facebook';
		$contactmethods['linkedin'] = 'LinkedIn';
		$contactmethods['pinterest'] = 'Pinterest';
		$contactmethods['instagram'] = 'Instagram';
		$contactmethods['link'] = 'Any Link';
		return $contactmethods;
	}
	add_filter('user_contactmethods','wellcenter_new_contactmethods',10,1);
}

//Breadcrumbs
if ( ! function_exists ( 'wellcenter_breadcrumbs' ) ) {
	function wellcenter_breadcrumbs() {
		if (!is_home()) {
			echo '<span class="crumb crumb_home"><a href="'. esc_url(home_url('/')).'">';
			echo esc_html__('Home','wellcenter');
			echo "</a></span>
		";
			if ('event' == get_post_type()) {
			echo '<span class="crumb crumb_events">';
				$themnific_redux = get_option( 'themnific_redux' );
				if(empty($themnific_redux['tmnf-events-url'])) {echo esc_html__('Events','wellcenter');} else {
					echo '<a href="'. esc_url($themnific_redux['tmnf-events-url']).'">';
					echo esc_html__('Events','wellcenter');
					echo '</a>';
				}
			echo '</span>';
			}
			if (is_category() || is_single()) {
				echo '<span class="crumb crumb_category">'; the_category(', '); echo '</span>';
				if (is_single()) {
					echo '<span class="crumb">';
					echo the_title().'</span>';
				}
		} elseif (is_page()) {
			global $post;
			if($post->post_parent){
				echo '<span class="crumb crumb_single"> <a href="'. get_permalink( $post->post_parent ) .'">';
				echo get_the_title($post->post_parent).'</a></span><span class="crumb">';
				echo the_title().'</span>';
			} else {
				echo '<span class="crumb">';
				echo the_title();
				echo '</span>';
			}
		} 
		}
	}
}


// register custom fonts for Gutenberg

add_action( 'after_setup_theme', 'wellcenter_gutenberg_css' );
 
function wellcenter_gutenberg_css(){
 
	add_theme_support( 'editor-styles' ); 
	add_editor_style( 'styles/style-editor.css' ); 
	add_editor_style( 'https://fonts.googleapis.com/css?family=Jost:400,400i,500,600,700' );
 
}

// remove mystery bar on mobile
add_action('get_header', 'wellcenter_filter_head');
function wellcenter_filter_head() {
   remove_action('wp_head', '_admin_bar_bump_cb');
}

// span to default widgets
function wellcenter_cat_count_span($links) {
  $links = str_replace('</a> (', '</a> <span class="cat_nr">', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;
}
add_filter('wp_list_categories', 'wellcenter_cat_count_span');



function wellcenter_archive_count($links) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="cat_nr">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}
add_filter('get_archives_link', 'wellcenter_archive_count');

add_filter('widget_text','do_shortcode');

// remove default styling Events Manager
add_filter('em_get_template_classes', '__return_empty_array');

/* That's all! */

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328409&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>