<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return; 
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "themnific_redux";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Wellcenter - admin panel', 'wellcenter' ),
        'page_title'           => __( 'Wellcenter admin panel', 'wellcenter' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => true,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'dev_mode'             => false,
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
                    'href'   => 'https://themnific.com/docs/wellcenter/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Documentation', 'wellcenter' ),
    );

    $args['admin_bar_links'][] = array(
                    'href'   => 'https://themnific.com/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Our Themes', 'wellcenter' ),
    );

    // Add content after the form.
    $args['footer_text'] = __( '<p>Themnific Themes</p>', 'wellcenter' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    // -> START Fields
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'General Settings','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-cogs',
                    'fields' => array( // header end
					

                        array(
                            'id'       => 'tmnf-main-logo',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
							'url'      => true,
                            'title'    => esc_html__( 'Main Logo','wellcenter' ),
                            'desc'     => esc_html__( 'Upload a logo for your theme','wellcenter' ),
                        ),
						
                        array(
                            'id'       => 'wellcenter-blog-label',
                            'type'     => 'text',
                            'title'    => esc_html__('News / Blog Title', 'wellcenter' ),
                            'subtitle'     => esc_html__('Write any label for blog/news page title.', 'wellcenter' ),
                            'default'  => esc_html__('News', 'wellcenter' ),
                        ),
						
												
                      	array(
                            'id'       => 'tmnf-uppercase',
                            'type'     => 'radio',
                            'title'    => esc_html__('Uppercase Fonts','wellcenter'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'upper_none' => esc_html__('None','wellcenter'),
                                'upper' => esc_html__('Minimal','wellcenter'),
                                'upper upper_medium' => esc_html__('Medium','wellcenter'),
                            ),
                            'default'  => 'upper'
                        ),
												
                      	array(
                            'id'       => 'tmnf-image-filter',
                            'type'     => 'radio',
                            'title'    => esc_html__('Images Filter','wellcenter'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'image_css_none' => esc_html__('None','wellcenter'),
                                'image_css_desaturate' => esc_html__('Desaturate','wellcenter'),
                                'image_css_desaturate_half' => esc_html__('Desaturate 50%','wellcenter'),
                                'image_css_sepia' => esc_html__('Sepia','wellcenter'),
                                'image_css_bright' => esc_html__('Bright','wellcenter'),
                            ),
                            'default'  => 'image_css_none'
                        ),
						
						array(
                            'id'       => 'tmnf-mailchimp',
                            'type'     => 'text',
                            'title'    => esc_html__( 'MailChimp Shortcode','wellcenter' ),
							'default'  => '',
                            'validate' => 'html',
						),
						
						
                    )
					
					// section end
    ) );
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );
	
	
	
	
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Primary Styling','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end



						array(
                            'id'          => 'wellcenter-body-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Typography','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
							'all_styles'  => true,
                            'output'      => array( 'body,input,button,select,textarea,#wpmem_reg fieldset,#wpmem_login fieldset' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as the general text.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#010e30',
                                'font-style'  => '400',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '19px',
                            ),
                        ),

                        array(
                            'id'       => 'wellcenter-background',
                            'type'     => 'background',
                            'title'    => esc_html__( 'Main Body Background','wellcenter' ),
                            'subtitle' => esc_html__( 'Body background with image, color, etc.','wellcenter' ),
							'transparent' => false,
                            'output'   => array('body,.give-btn' ),
                            'default'     => array(
                                'background-color'       => '#fff',
                            ),
                        ),
						
						array(
							'id'        => 'wellcenter-color-ghost',
							'type'      => 'color',
							'title'     => esc_html__('Ghost Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick an alternative background color (similar to Main Body Background)','wellcenter'),
							'transparent' => false,
							'default'   => '#f7f7f7',
							'output'    => array(
								'background-color' => '.ghost,.single .give-goal-progress,.sidebar_item,#comments .navigation a,a.page-numbers,.page-numbers.dots,.postinfo .mc4wp-form,.tmnf_tags a'
							)
						),

                        array(
                            'id'       => 'wellcenter-link-color',
                            'type'     => 'link_color',
                            'title'    => esc_html__( 'Links Color Option','wellcenter' ),
                            'subtitle' => esc_html__( 'Pick a link color','wellcenter' ),
							'output'   => array( 'a' ),
                            'default'  => array(
                                'regular' => '#0d3559',
                                'hover'   => '#c06c84',
                                'active'  => '#000',
                            )
                        ),
						

						
						array(
							'id'        => 'wellcenter-color-entry-link',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts)','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'color' => '.tmnf_entry p a,.tmnf_entry ol a,.tmnf_entry ul a,.elementor-text-editor a',
							)
						),
						

						
						array(
							'id'        => 'wellcenter-color-entry-link-hover',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts): Hover Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'background-color' => '.tmnf_entry p a:hover,.tmnf_entry li a:hover',
							)
						),
						
                        array(
                            'id'       => 'wellcenter-primary-border',
							'type'      => 'color',
							'title'     => esc_html__('Borders Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for primary borders','wellcenter'),
							'transparent' => false,
							'default'   => '#efefef',
							'output'    => array(
								'border-color' => '.tmnf_border,.head_logo_below #header.tmnf_border,.sidebar_item,.event_header p,input, textarea,select,.sidebar_item li,.comment-body,.tagcloud a,.page-numbers,.nav_item a,.tmnf_tags a,.postinfo .mc4wp-form,table,table th,table td,.wp-block-search .wp-block-search__input',
							)
						),
						
						array(
							'id'        => 'wellcenter-text-sidebar',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Text Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for sidebar text.','wellcenter'),
							'transparent' => false,
							'default'   => '#5b5f77',
							'output'    => array(
								'color' => '#sidebar,.post-pagination span',
							)
						),
						
						array(
							'id'        => 'wellcenter-links-sidebar',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Link Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for sidebar links.','wellcenter'),
							'transparent' => false,
							'default'   => '#0b314f',
							'output'    => array(
								'color' => '.widgetable a',
							)
						),
						
						array(
							'id'        => 'wellcenter-links-sidebar-hover',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Link: Hover Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for sidebar links.','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'color' => '.widgetable a:hover',
							)
						),
                    )

					// section end
    ) );
	// Primary styling THE END
	
	
	
	
	
	
	// HEADER STYLING
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Header Styling','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
										
                      	array(
                            'id'       => 'tmnf-header-fullwidth',
                            'type'     => 'radio',
                            'title'    => esc_html__('Header: Width','wellcenter'),
                            'subtitle' => esc_html__('Select layout for your header','wellcenter'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'header_boxed' => esc_html__('Boxed Header','wellcenter'),
                                'header_fullwidth' => esc_html__('Full-Width Header','wellcenter'),
                            ),
                            'default'  => 'header_boxed'
                        ),

                        array(
                            'id'       => 'wellcenter-bg-header',
                            'type'     => 'background',
                            'title'    => esc_html__( 'Header: Background','wellcenter' ),
                            'subtitle' => esc_html__( 'Body background with image, color, etc.','wellcenter' ),
							'transparent' => false,
                            'output'   => array('#header,.header_transparent .tmnf_menu_row.scrollDown' ),
                            'default'     => array(
                                'background-color'       => '#fff',
                            ),
                        ),

                        array(
                            'id'       => 'wellcenter-bg-header-alt',
                            'type'      => 'color',
                            'title'    => esc_html__( 'Header: Background Alternative','wellcenter' ),
                            'transparent' => false,
							'default'   => '#f4f4f4',
							'output'    => array(
								'background-color' => '.tmnf_menu_row::after,#add-nav::after',
							)
                        ),


						array(
                            'id'          => 'wellcenter-site-title',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Site Title','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h1.logo' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for large headings (e.g. single post title).','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '700',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '35px',
                            ),
                        ),
						
						array(
							'id'        => 'wellcenter-link-title',
							'type'      => 'color',
							'title'     => esc_html__('Title Link Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for header links.','wellcenter'),
							'transparent' => false,
							'default'   => '#355c7d',
							'output'    => array(
								'color' => '#add-nav a,#header .tmnf_social_icons li a',
							)
						),
						
						array(
							'id'        => 'wellcenter-menu-bg',
							'type'      => 'color',
							'title'     => esc_html__('Navigation: Background','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'background-color' => '#navigation',
							)
						),
						

						array(
                            'id'          => 'wellcenter-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Navigation: Typography','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.nav>li>a,.header_icon a' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#fff',
                                'font-weight'  => '700',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '17px',
                            ),
                        ),
						
						array(
							'id'        => 'wellcenter-hover-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Navigation Links: Hover Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a hover color for header links.','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'border-color' => '.nav li.current-menu-item>a,.nav >li>a:hover,#main-nav li.current-menu-ancestor>a',
							)
						),
						
						array(
							'id'        => 'wellcenter-borders-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Header Borders Color','wellcenter'),
							'transparent' => false,
							'default'   => '#efefef',
							'output'    => array(
								'border-color' => '#header.tmnf_border,.tmnf_menu_row,.header_icon,.tmnf_respo_magic #navigation,#header .tmnf_social_icons li a',
							)
						),
						

					
						array(
							'id'   => 'info_submenu',
							'type' => 'info',
							'title' => esc_html__('Sub-menu + Special menu button','wellcenter'),
							'style' => 'success',
						),
						
						
						
						array(
							'id'        => 'wellcenter-sub-bg-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Sub-menu Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for header text.','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'background-color' => '.nav li ul',
								'border-left-color' => '.nav>li>ul:after,.nav > li.mega:hover::after',
								'border-right-color' => 'body.rtl .nav>li>ul:after,body.rtl .nav > li.mega:hover::after',
							)
						),


						array(
                            'id'          => 'wellcenter-sub-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Sub-menu Typography','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.nav ul li>a,.tmnf_tagline' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#fff',
                                'font-weight'  => '400',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '16px',
                            ),
                        ),
						

						
						
						array(
							'id'        => 'wellcenter-special-bg',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button: Background Color','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'background-color' => '.show-menu,#main-nav>li.special>a',
								'color' => '#add-nav li i',
							)
						),
						
						array(
							'id'        => 'wellcenter-special-bg-hover',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button: Hover Background Color','wellcenter'),
							'transparent' => false,
							'default'   => '#355c7d',
							'output'    => array(
								'background-color' => '.show-menu:hover,#main-nav>li.special>a:hover',
							)
						),
						
						
						array(
							'id'        => 'wellcenter-special-text',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button: Text Color','wellcenter'),
							'transparent' => false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '.show-menu,#main-nav>li.special>a,#main-nav>li.special>a:hover i',
							)
						),


						array(
							'id'   => 'info_spacing',
							'type' => 'info',
							'title' => esc_html__('Spacing of the Header','wellcenter'),
							'style' => 'success',
						),

                        array(
                            'id'             => 'wellcenter-width-header',
                            'type'           => 'dimensions',
                            'output'   => array( '#titles' ),
                            'units'          => 'px', 
                            'units_extended' => 'true',  
                            'height'          => false, 
                            'title'          => esc_html__( 'Header Title/Logo Width Option','wellcenter' ),
                            'subtitle'       => esc_html__( 'Choose the width limitation for the header logo.','wellcenter' ),
                            'default'        => array(
                                'width'  => '220px',
                            )
                        ),

                        array(
                            'id'       => 'wellcenter-spacing-header',
                            'type'     => 'spacing',
                            'output'   => array( '#titles .logo,#header .tmnf_social_icons' ),
                            'mode'     => 'margin',
                            'all'      => false,
                            'right'         => false,    
                            'left'          => false,     
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Header Title/Logo Spacing','wellcenter' ),
                            'subtitle' => esc_html__( 'Choose the margin for the header logo.','wellcenter' ),
                            'default'  => array(
                                'margin-top'    => '60px',
                                'margin-bottom' => '35px',
                            )
                        ),
						

                        array(
                            'id'       => 'wellcenter-spacing-nav',
                            'type'     => 'spacing',
                            'output'   => array( '#navigation>ul>li>a,#add-nav' ),
                            'mode'     => 'padding',
                            'all'      => false,
                            'right'         => false,    
                            'left'          => false,     
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Header Navigation Spacing','wellcenter' ),
                            'subtitle' => esc_html__( 'Choose the margin for header navigation.','wellcenter' ),
                            'default'  => array(
                                'padding-top'    => '45px',
                                'padding-bottom' => '39px',
                            )
                        ),

                    )
					// section end
    ) );
	// header styling THE END
	
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Footer Styling','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
						
						array(
							'id'        => 'wellcenter-color-myfooter',
							'type'      => 'background',
							'title'     => esc_html__('Footer: Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a background color for the footer.','wellcenter'),
							'transparent' => false,
                            'output'   => array('#footer,#footer .searchform input.s,.footop-right' ),
                            'default'     => array(
                                'background-color'       => '#af6278',
                            ),
						),
						
						array(
							'id'        => 'wellcenter-text-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Text: Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for footer links.','wellcenter'),
							'transparent' => false,
							'default'   => '#e2b3c0',
							'output'    => array(
								'color' => '#footer p,#footer,#footer h4,#footer .bottom-menu a',
							)
						),
						
						array(
							'id'        => 'wellcenter-links-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links: Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for footer links.','wellcenter'),
							'transparent' => false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '#footer a,#footer a span,#footer h2,#footer h3,#footer .meta,#footer .meta a,#footer .searchform input.s',
							)
						),
						
						array(
							'id'        => 'wellcenter-hover-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links: Hover Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a hover color for footer links.','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'color' => '#footer a:hover,#footer a:hover span',
							)
						),
						
						
                        array(
                            'id'       => 'wellcenter-footer-border',
							'type'      => 'color',
							'title'     => esc_html__('Footer: Borders','wellcenter'),
							'subtitle'  => esc_html__('Pick a color for footer borders.','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'border-color' => '#footer .tmnf_border,.tmnf_foocol li,#footer a,#footer .tmnf_social_icons li a,#footer .searchform input.s,#footer input,#footer table,#footer table th,#footer table td',
							)
						), 
						

						array(
							'id'   => 'info_special_footer',
							'type' => 'info',
							'title' => esc_html__('Special Footer Section / Call to Action Section (above the footer)','wellcenter'),
							'style' => 'success',
						),	
						
						array(
                            'id'       => 'tmnf-header-image',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
							'url'      => true,
                            'title'    => esc_html__( 'Footer: Call to Action / Bg Image', 'wellcenter' ),
                            'subtitle'     => esc_html__( 'Recommended size 1800x400px', 'wellcenter' ),
                        ),


			
						array(
                            'id'       => 'tmnf-footer-editor',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Footer: Call to Action / Heading','wellcenter' ),
                            'subtitle' => esc_html__( 'Just like a text box widget.','wellcenter' ),
                            'desc'     => esc_html__( 'This field is HTML validated!','wellcenter' ),
							'default'  => '',
                            'validate' => 'html',
						),

						array(
                            'id'       => 'tmnf-footer-button-label',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Footer: Call to Action / Button: Label','wellcenter' ),
							'default'  => '',
                            'validate' => 'html',
						),

						
                        array(
                            'id'       => 'tmnf-footer-button-url',
                            'type'     => 'text',
                            'title'    => esc_html__('Footer: Call to Action / Button URL', 'wellcenter' ),
                            'validate' => 'url',
                            'default'  => '',
                        ),
						
						array(
                            'id'       => 'wellcenter-footer-credits',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Footer Credits Text','wellcenter' ),
                            'subtitle' => esc_html__( 'Just like a text box widget.','wellcenter' ),
                            'desc'     => esc_html__( 'This field is HTML validated!','wellcenter' ),
							'default'  => 'Copyright © 2021 - Wellcenter Theme',
                            'validate' => 'html',
						),
                    )

					// section end
    ) );
	// footer styling THE END
	
	
	
	
	

    Redux::setSection( $opt_name, array(                    
					'title'  => esc_html__( 'Typography','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-bold',
                    'fields' => array( // header end
					
					
					
						
						
						
						array(
							'id'   => 'info_titles',
							'type' => 'info',
							'title' => esc_html__('Titles','wellcenter'),
							'style' => 'success',
						),	


						array(
                            'id'          => 'wellcenter-large',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Large Titles','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.large_title,.tmnf_titles_are_large h3' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for large headings (e.g. single post title).','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '700',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '55px',
                            ),
                        ),


						array(
                            'id'          => 'wellcenter-medium',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Medium Titles','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.medium_title,.tmnf_titles_are_medium h3' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for small headings (e.g. footer widgets).','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '700',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '36px',
                            ),
                        ),


						array(
                            'id'          => 'wellcenter-small',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Small Titles','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.small_title,.tmnf_titles_are_small h3' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for small headings (e.g. footer widgets).','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),
						
						


						array(
                            'id'          => 'wellcenter-buttons',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Buttons Typography','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '#submit,.tmnf_social_icons li a span,.mainbutton,.show-menu span,.post_nav_text,.tptn_title' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '15px',
                            ),
                        ),
						
						
						
						array(
							'id'   => 'info_headings',
							'type' => 'info',
							'title' => esc_html__('Basic (in a post) Headings','wellcenter'),
							'style' => 'success',
						),	


						array(
                            'id'          => 'wellcenter-h1',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H1 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h1' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H1.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '36px',
                            ),
                        ),
						
						array(
                            'id'          => 'wellcenter-h2',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H2 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h2,blockquote,.footer_tagline h2' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H2.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '30px',
                            ),
                        ),
						
						array(
                            'id'          => 'wellcenter-h3',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H3 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h3,.footer_button' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H3.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '24px',
                            ),
                        ),
						
						array(
                            'id'          => 'wellcenter-h4',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H4 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h4' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H4.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),
						
						array(
                            'id'          => 'wellcenter-h5',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H5 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h5' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H5.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '600',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '20px',
                            ),
                        ),	
						
						array(
                            'id'          => 'wellcenter-h6',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H6 Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( 'h6' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H6.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#0d3559',
                                'font-weight'  => '500',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '18px',
                            ),
                        ),
                    )

					// section end
    ) );
	// typography styling THE END
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Other Styling','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
						
	
						
						array(
                            'id'          => 'wellcenter-meta',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Meta Sections: Font Style','wellcenter' ),
                            'google'      => true,
                            'font-backup' => true,
                            'output'      => array( '.tmnf_meta,.crumb,.post_nav_text span,.tmnf_tags,.tptn_date' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for meta sections.','wellcenter' ),
                            'default'     => array(
                                'color'       => '#355c7d',
                                'font-weight'  => '500',
                                'font-family' => 'Jost',
                                'google'      => true,
                                'font-size'   => '13px',
                            ),
                        ),
						
						array(
							'id'        => 'wellcenter-meta-links',
							'type'      => 'color',
							'title'     => esc_html__('Meta Sections: Links Color','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'color' => '.tmnf_meta a'
								
							)
						),
						
						array(
							'id'        => 'wellcenter-color-dividers',
							'type'      => 'color',
							'title'     => esc_html__('Dividers: Background','wellcenter'),
							'transparent' => false,
							'default'   => '#355c7d',
							'output'    => array(
								'background-color' => 'a.mainbutton.inv,.tptn_posts_widget li::before,.tmnf_meta_categs,.give-btn.give-default-level',
								'color' => '.main-breadcrumbs span::after'
								
							)
						),
						
						array(
							'id'        => 'wellcenter-color-dividers-text',
							'type'      => 'color',
							'title'     => esc_html__('Dividers: Text','wellcenter'),
							'transparent' => false,
							'default'   => '#fff',
							'output'    => array(
								'color' => 'a.mainbutton.inv,.tptn_posts_widget li::before,.tmnf_meta_categs,.tmnf_meta_categs a,.give-btn.give-default-level',
								
							)
						),
						
						array(
							'id'        => 'wellcenter-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections, etc.','wellcenter'),
							'transparent' => false,
							'default'   => '#f67280',
							'output'    => array(
								'background-color' => '.ribbon,#woo-site button.button,#woo-site a.button,a.mainbutton,.wrapper a.checkout-button.button,.owl-nav>div,.cat_nr,#respond #submit,.page-numbers.current,#submit,input[type="submit"],input.button,button.submit,#comments .navigation a,.reply a,.post_pagination_inn,.tmnf_social_icons li a:hover,.wp-block-search .wp-block-search__button,.give-btn.give-btn-reveal,.give-btn.give-btn-modal',
								'border-color' => 'input.button,button.submit,.page-link>span',
								
							)
						),
						
						array(
							'id'        => 'wellcenter-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Links/Texts - Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections, etc.','wellcenter'),
							'transparent' => false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '.ribbon,.ribbon a,a.ribbon,.ribbon p,#footer .ribbon,#woo-site button.button,#woo-site a.button,.wrapper a.checkout-button.button,a.mainbutton,.owl-nav>div,.cat_nr,.page-numbers.current,.format-quote blockquote,.reply a,#respond #submit,input[type="submit"],.post_pagination p a span,.tmnf_social_icons li a:hover,#header .tmnf_social_icons li a:hover,#footer .tmnf_social_icons li a:hover,#footer .tmnf_social_icons li a:hover span,.wp-block-search .wp-block-search__button,.give-btn.give-btn-reveal,.give-btn.give-btn-modal',
							)
						),
						
						array(
							'id'        => 'wellcenter-hover-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Background Hover Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections, etc.','wellcenter'),
							'transparent' => false,
							'default'   => '#c06c84',
							'output'    => array(
								'background-color' => 'a.searchSubmit:hover,.ribbon:hover,a.mainbutton:hover,#woo-site button.button:hover,#woo-site a.button:hover,.wrapper a.checkout-button.button:hover,a.mainbutton,.meta_more a:hover,.nav-links>a:hover,span.page-numbers:hover,.tmnf_tags a:hover,.reply a:hover,input[type="submit"]:hover,h4.widget>span:after,.post_pagination p a:hover span,.owl-nav>div:hover,input[type="submit"]:hover',
								'border-color' => 'input.button:hover,button.submit:hover,.tmnf_tags a:hover'
							)
						),
						
						array(
							'id'        => 'wellcenter-hover-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Links/Texts - Hover Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections, etc.','wellcenter'),
							'transparent' => false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '#footer a.mainbutton:hover,.ribbon:hover,.ribbon:hover a,.ribbon a:hover,.ribbon:hover p,#footer .ribbon:hover,.entry a.ribbon:hover,#woo-site button.button:hover,#woo-site a.button:hover,.wrapper a.checkout-button.button:hover,a.mainbutton:hover,.nav-links>a:hover,span.page-numbers:hover,.tmnf_tags a:hover,.reply a:hover,input[type="submit"]:hover,.post_pagination p a:hover span,.owl-nav>div:hover,input[type="submit"]:hover',
							)
						),
						
						
						array(
							'id'        => 'wellcenter-images-bg',
							'type'      => 'color',
							'title'     => esc_html__('Images Background Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom background color for images.','wellcenter'),
							'transparent' => false,
							'default'   => '#424851',
							'output'    => array(
								'background-color' => '.imgwrap,.page_header_image,.post_nav_image,.owl-item,.item .sticky .item_inn,.footop.populated',
							)
						),
						
						
						
						array(
							'id'        => 'wellcenter-images-text',
							'type'      => 'color',
							'title'     => esc_html__('Images Text/Link Color','wellcenter'),
							'subtitle'  => esc_html__('Pick a custom text color for image texts (overlay)','wellcenter'),
							'transparent' => false,
							'default'   => '#fdfff9',
							'output'    => array(
								'color' => '.page_header_image,.page_header_image a,.page_header_image h1,.page_header_image p,.page_header_image .main_breadcrumbs span,.page_header_image .tmnf_archive_subtitle,.post_nav_image .arrow,.mag_item_overlay.has-post-thumbnail .item_inn a,.mag_item_overlay.has-post-thumbnail .item_inn p,.item .sticky .item_inn,.item .sticky .item_inn a,.item .sticky .item_inn p,.item .sticky:before,.evnt_date span,#footop.populated h2',
							)
						),
						
						
						array(
							'id'        => 'wellcenter-slider-overlay',
							'type'      => 'color',
							'title'     => esc_html__('Slider Overlay','wellcenter'),
							'transparent' => true,
							'default'   => '#8224e3',
							'output'    => array(
								'background-color' => '.slider_overlay_small',
							)
						),
                    )
					// section end
    ) );
	// other styling THE END
	
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );
	
	
	
	
	//POST SETTINGS
    Redux::setSection( $opt_name, array(
                   'title'  => esc_html__( 'Post Settings','wellcenter' ),
                    'desc'   => esc_html__( '','wellcenter' ),
                    'icon'   => 'el el-edit',
                    'fields' => array( // header end

						
                        array(
                            'id'       => 'tmnf-post-meta-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Disable "Meta" sections','wellcenter' ),
                            'subtitle' => esc_html__( 'Tick to disable post "information" - date, category, etc. below post titles','wellcenter' ),
                            'desc'     => esc_html__( '','wellcenter' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-author-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Author Box','wellcenter' ),
                            'desc'     => esc_html__( '','wellcenter' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-tags-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Tags Section','wellcenter' ),
                            'desc'     => esc_html__( '','wellcenter' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-related-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Related Post Section','wellcenter' ),
                            'desc'     => esc_html__( '','wellcenter' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-nextprev-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Next/Previous Post Section','wellcenter' ),
                            'desc'     => esc_html__( '','wellcenter' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
                    )
					// section end
    ) );
	// post settings THE END
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Social Networks','wellcenter'),
                    'icon'   => 'el el-share',
                    'fields' => array( // header end
				
					

                        array(
                            'id'       => 'tmnf-social-rss',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Rss Feed','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-facebook',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Facebook','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-twitter',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Twitter','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-tiktok',
                            'type'     => 'text',
                            'title'    => esc_html__( 'TikTok','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-pinterest',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Pinterest','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-instagram',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Instagram','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-youtube',
                            'type'     => 'text',
                            'title'    => esc_html__( 'You Tube','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-vimeo',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Vimeo','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-tumblr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Tumblr','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-500',
                            'type'     => 'text',
                            'title'    => esc_html__( '500px','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-flickr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Flickr','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-linkedin',
                            'type'     => 'text',
                            'title'    => esc_html__( 'LinkedIn','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-foursquare',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Foursquare','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-dribbble',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Dribbble','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-skype',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Skype','wellcenter'),
                            'subtitle' => esc_html__( 'Enter skype URL','wellcenter'),
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-stumbleupon',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Stumbleupon','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-github',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Github','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-soundcloud',
                            'type'     => 'text',
                            'title'    => esc_html__( 'SoundCloud','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-spotify',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Spotify','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-xing',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Xing','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),

                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-whatsapp',
                            'type'     => 'text',
                            'title'    => esc_html__( 'WhatsApp','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-vk',
                            'type'     => 'text',
                            'title'    => esc_html__( 'VK','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-snapchat',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Snapchat','wellcenter'),
                            'subtitle' => esc_html__( 'Enter full URL','wellcenter'),
                            'validate' => 'url',
                        ),
                    )
					// section end
    ) );
	// social networks THE END	
	
	
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );


    /*
     * <--- END SECTIONS
     */
