<?php
add_action('widgets_init', 'wellpress_blog');

function wellpress_blog()
{
	register_widget('wellpress_blog');
}

class wellpress_blog extends WP_Widget {
	
	public function __construct() {
		$widget_ops = array('classname' => 'wellpress_blog', 'description' => esc_html__('!!Posts block for homepage only!!','everify'));
       	parent::__construct(false, esc_html__('Themnific: Blog','everify'),$widget_ops);  
	}
	
	function widget($args, $instance)
	{
		extract($args);
		
		$layout = isset( $instance['layout'] ) ? esc_attr( $instance['layout'] ) : '';
		$post_type = 'all';
		$categories = isset( $instance['categories'] ) ? esc_attr( $instance['categories'] ) : '';
		$posts = isset( $instance['posts'] ) ? esc_attr( $instance['posts'] ) : '';
		$offset_posts = isset( $instance['offset_posts'] ) ? esc_attr( $instance['offset_posts'] ) : '';
		
		echo wp_kses_post($before_widget);
		?>
		
		<?php
		$post_types = get_post_types();
		unset($post_types['page'], $post_types['attachment'], $post_types['revision'], $post_types['nav_menu_item']);
		
		if($post_type == 'all') {
			$post_type_array = $post_types;
		} else {
			$post_type_array = $post_type;
		}
		?>
        
        <div class="widget_block">
            
			<?php
			$recent_posts = new WP_Query(array(
				'showposts' => $posts,
				'ignore_sticky_posts' => 1,
				'cat' => $categories,
				'offset' => esc_attr($offset_posts),
				'post_status' => 'publish'
			));
		
			wp_enqueue_script('masonry');		
			wp_enqueue_script('masonry-start', get_template_directory_uri() .'/js/masonry.start.js',array( 'jquery' ),'', true);
			
			?>
            <div class="blogger tmnf_columns_wrap">
			<?php  while($recent_posts->have_posts()): $recent_posts->the_post(); ?>
            
            	<div class="item tmnf_column <?php echo esc_attr($layout); ?>">

				<?php if(has_post_format('quote')){get_template_part('/post-types/post-quote-index');} else {
                    get_template_part('/post-types/post-classic');
                }?>
                
                </div>

			<?php endwhile;wp_reset_postdata(); ?>
			</div>
            
			<div class="clearfix"></div>
            
        </div>
		
		<?php
		echo wp_kses_post($after_widget);
	}
	
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['layout'] = $new_instance['layout'];
		$instance['post_type'] = 'all';
		$instance['categories'] = $new_instance['categories'];
		$instance['posts'] = sanitize_text_field($new_instance['posts']);
		$instance['offset_posts'] = sanitize_text_field($new_instance['offset_posts']);
		
		return $instance;
	}

	function form($instance)
	{
		$defaults = array('post_type' => 'all', 'categories' => 'all', 'layout' => 'tmnf_column_3','posts' => 4,'offset_posts' => '');
		$modern_style        = isset( $instance['modern_style'] ) ? (bool) $instance['modern_style'] : false;
		$instance = wp_parse_args((array) $instance, $defaults); ?>

		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php esc_html_e('Filter by Category','everify'); ?></label> 
			<select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="widefat categories" style="width:100%;">
				<option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>>all categories</option>
				<?php $categories = get_categories('hide_empty=0&depth=1&type=post'); ?>
				<?php foreach($categories as $category) { ?>
				<option value='<?php echo esc_attr($category->term_id); ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_attr($category->cat_name); ?></option>
				<?php } ?>
			</select>
		</p>
        
        <p>
			<label for="<?php echo esc_attr($this->get_field_id('layout')); ?>"><?php esc_html_e('Layout','everify'); ?>: </label>
			<select id="<?php echo esc_attr($this->get_field_id('layout')); ?>" name="<?php echo esc_attr($this->get_field_name('layout')); ?>" class="widefat">
				<?php 
				$layout_options = apply_filters('em_widget_order_ddm', array(
					'tmnf_column_3' => esc_html__('4 Columns','everify'),
					'tmnf_column_4' => esc_html__('3 Columns','everify'),
					'tmnf_column_6' => esc_html__('2 Columns','everify'),
					'tmnf_column_12' => esc_html__('1 Columns','everify'),
				)); 
				?>
				<?php foreach( $layout_options as $key => $value) : ?>   
	 			<option value='<?php echo esc_attr($key); ?>' <?php echo esc_attr($key == $instance['layout']) ? "selected='selected'" : ''; ?>>
	 				<?php echo esc_html($value); ?>
	 			</option>
				<?php endforeach; ?>
			</select>
        </p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('posts')); ?>"><?php esc_html_e('Number of posts','everify'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('posts')); ?>" name="<?php echo esc_attr($this->get_field_name('posts')); ?>" value="<?php echo esc_attr($instance['posts']); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>"><?php esc_html_e('Offset posts','everify'); ?></label>
			<input class="widefat" style="width: 40px;" id="<?php echo esc_attr($this->get_field_id('offset_posts')); ?>" name="<?php echo esc_attr($this->get_field_name('offset_posts')); ?>" value="<?php echo esc_attr($instance['offset_posts']); ?>" />
		</p>
		

	<?php }
}
?>